import {
  className,
  mergeData,
  renderRule,
  validate,
  isString
} from '../../core/utils'
import { COLOR } from '../../core/constants'
import rules from './text.rules'

const TYPES = [ 'h1', 'h2', 'h3', 'body', 'meta' ]

const validator = validate(TYPES)

export default {
  functional: true,
  inject: [
    'fela',
    'croudClassName'
  ],
  props: {
    text: {
      type: String
    },
    tag: {
      type: String,
      default: 'span'
    },
    type: {
      type: String,
      enums: TYPES,
      validator
    },
    color: {
      type: String,
      default: COLOR.SLATE
    },
    display: {
      type: String
    },
    bold: {
      type: Boolean
    },
    size: {
      type: [ String, Number ]
    },
    lineHeight: {
      type: [ String, Number ]
    },
    align: {
      type: String
    },
    uppercase: {
      type: Boolean
    },
    ellipsis: {
      type: Boolean
    }
  },
  render(h, ctx) {
    const { tag, text, type: propsType } = ctx.props
    const tagType = validator(tag) ? tag : 'body'
    const type = isString(propsType) ? propsType : tagType
    const props = Object.assign({}, ctx.props, { type })
    const classes = renderRule(ctx, rules.text, props)
    return h(tag, mergeData(ctx, {
      class: className(ctx, 'text', classes)
    }), text ? text : ctx.children)
  }
}
