import { objectEach } from 'fast-loops'
import * as constants from './core/constants'
import * as easing from './core/easing'
import * as utils from './core/utils'
import staticStyles from './fela/static-styles'
import createConfig from './fela/config'
import components from './components'
import icons from './core/icons'
import logos from './core/logos'
import rules from './rules'

const isRoot = (vm) => vm === vm.$root

const install = (Vue, options = {}) => {
  const {
    linkName = 'router-link',
    namespace = 'cui',
    register = true
  } = options

  const croudClassName = (value, classes) => [
    value ? `${namespace}-${value}` : null
  ].concat(classes)

  Vue.mixin({
    provide() {
      return isRoot(this) ? {
        croudLinkName: linkName,
        croudClassName
      } : null
    }
  })

  Vue.prototype.$ccn = croudClassName
  Vue.prototype.$con = constants

  if (register) {
    objectEach(components, (component, key) => {
      const name = utils.camelToKebab(key)
      Vue.component(`${namespace}-${name}`, component)
    })
  }
}

export {
  createConfig,
  staticStyles,
  components,
  constants,
  easing,
  icons,
  logos,
  rules,
  utils
}

export default {
  install
}
